This project contains functions and classes that help with plumbing-type programing.

Full documentation is available at:
http://xapple.github.com/plumbing/

[![changelog](http://allmychanges.com/p/python/plumbing/badge/)](http://allmychanges.com/p/python/plumbing/?utm_source=badge)
